@@ -1,4 +1,4 @@
-from typing import Sequence, Optional, Dict, Any, Callable, List
+from typing import Sequence, Optional, Dict, Any, Callable
 
 import json
 import os
@@ -124,12 +124,6 @@ class BaseNLPModel:
 
     @classmethod
     def _filter_config(cls, config) -> Dict[str, Any]:
-        config.pop("inputs", None)
-        config.pop("input_types", None)
-        config.pop("input_shapes", None)
-        config.pop("outputs", None)
-        config.pop("output_types", None)
-        config.pop("output_shapes", None)
         return config
 
     @classmethod
