@@ -8,47 +8,44 @@ import tensorflow as tf
 from sknlp.vocab import Vocab
 from sknlp.data import ClassificationDataset
 from sknlp.metrics import PrecisionWithLogits, RecallWithLogits
-from sknlp.losses import SoftFScoreLoss
 from sknlp.callbacks import FScore
 
 from ..supervised_model import SupervisedNLPModel
 from ..text2vec import Text2vec
 
-from .utils import (
-    logits2probabilities,
-    probabilities2classes,
-    classification_fscore
-)
+from .utils import logits2probabilities, probabilities2classes, classification_fscore
 
 
 class DeepClassifier(SupervisedNLPModel):
-
     def __init__(
         self,
         classes: Sequence[str],
         is_multilabel: bool = True,
         max_sequence_length: Optional[int] = None,
         sequence_length: Optional[int] = None,
-        segmenter: str = "jieba",
+        segmenter: Optional[str] = "jieba",
         embedding_size: int = 100,
         text2vec: Optional[Text2vec] = None,
         loss: str = None,
         **kwargs
     ):
-        super().__init__(classes,
-                         max_sequence_length=max_sequence_length,
-                         sequence_length=sequence_length,
-                         segmenter=segmenter,
-                         embedding_size=embedding_size,
-                         text2vec=text2vec,
-                         task="classification",
-                         **kwargs)
+        classes = list(classes)
+        if not is_multilabel and "NULL" != classes[0]:
+            classes.insert(0, "NULL")
+        super().__init__(
+            classes,
+            max_sequence_length=max_sequence_length,
+            sequence_length=sequence_length,
+            segmenter=segmenter,
+            embedding_size=embedding_size,
+            text2vec=text2vec,
+            task="classification",
+            **kwargs
+        )
         self._is_multilabel = is_multilabel
         self._loss = loss
 
     def get_loss(self):
-        if self._loss is not None:
-            return SoftFScoreLoss(is_multilabel=self._is_multilabel, from_logits=True)
         if self._is_multilabel:
             return tf.keras.losses.BinaryCrossentropy(from_logits=True)
         else:
@@ -61,18 +58,16 @@ class DeepClassifier(SupervisedNLPModel):
         if self._is_multilabel:
             return [PrecisionWithLogits(), RecallWithLogits()]
         else:
-            return [PrecisionWithLogits(logits2scores="softmax"),
-                    RecallWithLogits(logits2scores="softmax")]
+            return [
+                PrecisionWithLogits(logits2scores="softmax"),
+                RecallWithLogits(logits2scores="softmax"),
+            ]
 
     def get_monitor(self) -> str:
         return "val_f-score"
 
     def create_dataset_from_df(
-        self,
-        df: pd.DataFrame,
-        vocab: Vocab,
-        segmenter: str,
-        labels: Sequence[str]
+        self, df: pd.DataFrame, vocab: Vocab, segmenter: str, labels: Sequence[str]
     ) -> ClassificationDataset:
         return ClassificationDataset(
             vocab,
@@ -80,9 +75,12 @@ class DeepClassifier(SupervisedNLPModel):
             df=df,
             is_multilabel=self._is_multilabel,
             max_length=self._max_sequence_length,
-            text_segmenter=segmenter
+            text_segmenter=segmenter,
         )
 
+    def dummy_y(self, X: Sequence[str]) -> List[str]:
+        return ["O" for _ in range(len(X))]
+
     def predict_proba(
         self,
         X: Sequence[str] = None,
@@ -145,5 +143,5 @@ class DeepClassifier(SupervisedNLPModel):
         return {
             **super().get_custom_objects(),
             "PrecisionWithLogits": PrecisionWithLogits,
-            "RecallWithLogits": RecallWithLogits
+            "RecallWithLogits": RecallWithLogits,
         }
