@@ -4,6 +4,7 @@ import os
 import logging
 
 import tensorflow as tf
+from tensorflow.python.keras.engine import training
 import tensorflow_addons as tfa
 import pandas as pd
 
@@ -20,9 +21,7 @@ stream = logging.StreamHandler()
 logger.addHandler(stream)
 
 
-
 class SupervisedNLPModel(BaseNLPModel):
-
     def __init__(
         self,
         classes: Sequence[str],
@@ -90,11 +89,7 @@ class SupervisedNLPModel(BaseNLPModel):
 
     @classmethod
     def create_dataset_from_df(
-        cls,
-        df: pd.DataFrame,
-        vocab: Vocab,
-        segmenter: str,
-        labels: Sequence[str]
+        cls, df: pd.DataFrame, vocab: Vocab, segmenter: str, labels: Sequence[str]
     ) -> NLPDataset:
         raise NotImplementedError()
 
@@ -104,7 +99,7 @@ class SupervisedNLPModel(BaseNLPModel):
         y: Sequence[str],
         dataset: NLPDataset,
         batch_size: int,
-        shuffle: bool = True
+        shuffle: bool = True,
     ) -> tf.data.Dataset:
         assert not ((X is None or y is None) and dataset is None)
 
@@ -152,15 +147,25 @@ class SupervisedNLPModel(BaseNLPModel):
         log_file: Optional[str] = None,
         verbose: int = 2
     ) -> None:
-        assert not (self._text2vec is None and X is None), \
-            "When text2vec is not given, X must be provided"
+        assert not (
+            self._text2vec is None and X is None
+        ), "When text2vec is not given, X must be provided"
 
-        self.train_dataset = self.prepare_tf_dataset(X, y, dataset, batch_size)
-        if ((valid_X is None or valid_y is None) and valid_dataset is None):
+        self.train_dataset = self.prepare_tf_dataset(
+            X,
+            y,
+            dataset,
+            batch_size,
+        )
+        if (valid_X is None or valid_y is None) and valid_dataset is None:
             self.valid_dataset = None
         else:
             self.valid_dataset = self.prepare_tf_dataset(
-                valid_X, valid_y, valid_dataset, batch_size, shuffle=False
+                valid_X,
+                valid_y,
+                valid_dataset,
+                batch_size,
+                shuffle=False,
             )
         if not self._built:
             self.build()
@@ -184,13 +189,15 @@ class SupervisedNLPModel(BaseNLPModel):
         weight_decay = WeightDecayScheduler(wd_scheduler, verbose=verbose)
         callbacks = [*callbacks, lr_decay, weight_decay]
         if enable_early_stopping:
-            callbacks.append(tf.keras.callbacks.EarlyStopping(
-                monitor=self.get_monitor(),
-                min_delta=early_stopping_min_delta,
-                patience=early_stopping_patience or lr_update_epochs,
-                mode="max",
-                restore_best_weights=early_stopping_use_best_epoch
-            ))
+            callbacks.append(
+                tf.keras.callbacks.EarlyStopping(
+                    monitor=self.get_monitor(),
+                    min_delta=early_stopping_min_delta,
+                    patience=early_stopping_patience or lr_update_epochs,
+                    mode="max",
+                    restore_best_weights=early_stopping_use_best_epoch,
+                )
+            )
         if log_file is not None:
             callbacks.append(tf.keras.callbacks.CSVLogger(log_file))
         self._model.fit(
@@ -198,9 +205,12 @@ class SupervisedNLPModel(BaseNLPModel):
             epochs=n_epochs,
             validation_data=self.valid_dataset,
             callbacks=callbacks,
-            verbose=verbose
+            verbose=verbose,
         )
 
+    def dummy_y(self, X: Sequence[str]) -> List[Any]:
+        raise NotImplementedError()
+
     def predict(
         self,
         X: Sequence[str] = None,
@@ -209,13 +219,9 @@ class SupervisedNLPModel(BaseNLPModel):
         batch_size: int = 128
     ) -> tf.Tensor:
         assert self._built
-        y = None if X is None else ["O" for _ in range(len(X))]
+        y = None if X is None else self.dummy_y(X)
         dataset = self.prepare_tf_dataset(X, y, dataset, batch_size, shuffle=False)
-
-        def _f(x, y):
-            return x
-
-        return self._model.predict(dataset.map(_f))
+        return self._model.predict(dataset)
 
     def score(
         self,
@@ -234,7 +240,7 @@ class SupervisedNLPModel(BaseNLPModel):
             "segmenter": self._segmenter,
             "classes": self.classes,
             "task": self._task,
-            "algorithm": self._algorithm
+            "algorithm": self._algorithm,
         }
 
     def save(self, directory: str) -> None:
@@ -255,7 +261,4 @@ class SupervisedNLPModel(BaseNLPModel):
         self._text2vec.save_vocab(d)
 
     def get_custom_objects(self) -> Dict[str, Any]:
-        return {
-            **super().get_custom_objects(),
-            "AdamW": tfa.optimizers.AdamW
-        }
\ No newline at end of file
+        return {**super().get_custom_objects(), "AdamW": tfa.optimizers.AdamW}
